.. _documentation-statistics-label:

===================
Notes on statistics
===================

The following urls are helpful to understand the statistical treatment of the uncertainties on the content of each bin of a histogram:

- `Note about uncertainties when the histogram entries are weighted. <https://www.pp.rhul.ac.uk/~cowan/stat/notes/errors_with_weights.pdf>`_
- `Presentation about asymmetrical uncertainties. <https://www.nikhef.nl/~ivov/Statistics/PoissonError/2017_05_15_PoissonError_LHCb_IvovanVulpen.pdf>`_

The uncertainty on the efficiency (ratio of two histograms h1 and h2 when the entries of h1 are a subset of the entries of h2) is calculated following equation (19) of:

- `T. Ullrich, Z. Xu, Treatment of Errors in Efficiency Calculations, arxiv: 0701199v1. <https://arxiv.org/pdf/physics/0701199v1.pdf>`_
